@@ -6,7 +6,7 @@ function (X, y, ind, tind, n, k, t., nT, w, w2, coef0 = rep(0, 4),
 {
 
     ## New KKP+SR estimator, Giovanni Millo 12/03/2013
-    ## structure:
+    ## structure: 
     ## a) specific part
     ## - set names, bounds and initial values for parms
     ## - define building blocks for likelihood and GLS as functions of parms
@@ -185,7 +185,7 @@ function (X, y, ind, tind, n, k, t., nT, w, w2, coef0 = rep(0, 4),
     nvcovpms <- length(nam.errcomp) - 1
     ## error handler here for singular Hessian cases
     covTheta <- try(solve(-myHessian), silent=TRUE)
-    if(class(covTheta) == "try-error") {
+    if(inherits(covTheta, "try-error")) {
         covTheta <- matrix(NA, ncol=nvcovpms+1,
                            nrow=nvcovpms+1)
         warning("Hessian matrix is not invertible")
